@@ -4,6 +4,7 @@ Tasks for our OPAL signals
 from celery import shared_task
 
 from opal.models import Patient, Episode
+from opal.core.subrecords import get_subrecord_from_api_name
 
 
 @shared_task
@@ -23,8 +24,9 @@ def episode_post_save(created, instance_id):
 
 
 @shared_task
-def subrecord_post_save(sender, created, instance_id):
+def subrecord_post_save(sender_api_name, created, instance_id):
     from opal.core.signals.worker import subrecord_post_save
+    sender = get_subrecord_from_api_name(sender_api_name)
     instance = sender.objects.get(id=instance_id)
     subrecord_post_save.send(sender, created=created, instance=instance)
     return
