@@ -14,14 +14,16 @@ subrecord_post_save = dispatch.Signal(providing_args=["created", "instance"])
 
 def post_save_worker_forwarder(sender, created=None, instance=None, **kwargs):
     from django.conf import settings
-    if 'djcelery' in settings.INSTALLED_APPS:
+    if 'django_celery_results' in settings.INSTALLED_APPS:
         from opal.core.signals import tasks
         if sender == models.Patient:
             tasks.patient_post_save.delay(created, instance.id)
         if sender == models.Episode:
             tasks.episode_post_save.delay(created, instance.id)
         if issubclass(sender, models.Subrecord):
-            tasks.subrecord_post_save.delay(sender, created, instance.id)
+            tasks.subrecord_post_save.delay(
+                sender.get_api_name(), created, instance.id
+            )
     return
 
 
