@@ -1,7 +1,7 @@
 """
 Unittests for opal.forms
 """
-from mock import MagicMock, patch
+from unittest.mock import MagicMock, patch
 
 from opal.core.test import OpalTestCase
 
