@@ -3,7 +3,7 @@ Tests for opal.models.UserProfile
 """
 from django.contrib.auth.models import User
 from django.test import TestCase
-from mock import patch
+from unittest.mock import patch
 
 from opal.models import UserProfile
 
